@@ -2,7 +2,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-mvs.el
-;; Release:      $efs release: 1.19 $
+;; Release:      $efs release: 1.20pre2 $
 ;; Version:      #Revision: 1.4 $
 ;; RCS:          
 ;; Description:  MVS support for efs
@@ -14,7 +14,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;; This file is part of efs. See efs.el for copyright
-;;; (it's copylefted) and warrranty (there isn't one) information.
+;;; (it's copylefted) and warranty (there isn't one) information.
 
 ;;; --------------------------------------------------------
 ;;; MVS support
@@ -24,7 +24,7 @@
 (require 'efs)
 
 (defconst efs-mvs-version
-  (concat (substring "$efs release: 1.19 $" 14 -2)
+  (concat (substring "$efs release: 1.20pre2 $" 14 -2)
 	  "/"
 	  (substring "#Revision: 1.4 $" 11 -2)))
 
